("A modifier" "Modifiktor A")
("GNU" "GNU")
("H modifier" "Modifiktor H")
("LaTeX" "LaTeX")
("M modifier" "Modifiktor M")
("TeX" "TeX")
("abbreviation" "zkratka")
("about" "o programu")
("about menu" "o programu")
("above" "nad")
("abstract" "abstrakt")
("accent" "akcent")
("accept" "akceptovat")
("accept all scripts" "povolit vechny skripty")
("accept no scripts" "nepovolit dn skripty")
("accept script" "povolit skript")
("acknowledgment" "podkovn")
("acronym" "akronym")
("action" "akce")
("activate" "aktivovat")
("acute" "rka")
("add switch after" "vloit pepna za")
("add switch before" "vloit pepna ped")
("address" "adresa")
("address block" "blok adresy")
("advanced" "pokroil")
("advanced layout features" "pokroil vlastnosti rozloen")
("after" "po")
("albanian" "albnsk")
("algorithm" "algoritmus")
("align cell to the bottom" "zarovnat buku dol")
("align cell to the left" "zarovnat buku doleva")
("align cell to the right" "zarovnat buku doprava")
("align cell to the top" "zarovnat buku nahoru")
("align table at base of left column" "zarovnat tabulku podle sloupku vlevo")
("align table at base of middle column" "zarovnat tabulku podle sloupku uprosted")
("align table at base of origin column" "zarovnat tabulku podle pvodnho sloupku")
("align table at base of right column" "zarovnat tabulku podle pvodnho sloupku vpravo")
("align table at fraction bar height" "zarovnat tabulku")
("align table at the base of bottom row" "zarovnat tabulku podle dku dole")
("align table at the base of middle row" "zarovnat tabulku podle dku uprosted")
("align table at the base of origin row" "zarovnat tabulku podle pvodnho dku")
("align table at the base of top row" "zarovnat tabulku podle dku nahoe")
("align table at the bottom" "zarovnat tabulku dol")
("align table at the center" "zarovnat tabulku na sted")
("align table at the horizontal center" "zarovnat tabulku doprosted")
("align table at the left" "zarovnat tabulku nalevo")
("align table at the top" "zarovnat tabulku nahoru")
("align table to the right" "zarovnat tabulku doprava")
("align text to the left" "zarovnat text doleva")
("align text to the right" "zarovnat text doprava")
("alignment" "zarovnn")
("all" "ve")
("allow" "povolit")
("allowed extension" "povolit rozen")
("allowed reduction" "povolit redukci")
("alpha release" "alpha release")
("alt key" "klvesa alt")
("and" "a")
("appendix" "dodatek")
("apply" "pouij")
("april" "duben")
("arab" "arabtina")
("archaic" "archaick")
("architecture" "architektura")
("argument" "argument")
("arithmetic" "aritmetick")
("armenian" "armnsk")
("arrow" "ipka")
("arrows" "ipky")
("article" "lnek")
("as on paper" "jako na pape")
("assign" "piadit")
("at fraction bar height" "na zlomkovou ru")
("at the baseline" "na a")
("at the bottom" "dol")
("at the left" "doleva")
("at the middle" "doprosted")
("at the right" "doprava")
("at the top" "nahoru")
("attach" "pipojit")
("attach buffer to which project" "pipojit snmek k projektu")
("august" "srpen")
("author" "autor")
("authorize" "autorizovat")
("automatic" "automatick")
("automatically generated content" "automaticky generovan obsah")
("axiom" "axim")
("background" "pozad")
("background color" "barva pozad")
("backward replace" "nahrazovat dozadu")
("backward search" "hledat dozadu")
("bad data format" "patn formt dat")
("bar" "pruh")
("bard" "bard")
("base level" "zkladn rove")
("bashkirian" "bashkrian")
("basic" "zkladn")
("basic data types" "zkladn datov typy")
("basic types" "zkladn typy")
("be useful" "bute uiten")
("become a TeXmacs developer" "state se vvojem TeXmacsu")
("before" "ped")
("begin" "zatek")
("below" "pod")
("beta release" "beta release")
("bibliography" "literatura")
("bibliography file" "soubor s literaturou")
("bibliography style" "styl pro literaturu")
("big" "velk")
("big figure" "velk obrzek")
("big operator" "velk opertor")
("big skip" "velk odstup")
("big table" "velk tabulka")
("binary operation" "binrn operace")
("binary relation" "binrn relace")
("black" "ern")
("blackboard bold" "blackboard tun")
("blackboard math" "blackboard matematick")
("blackletter" "blackletter")
("blue" "modr")
("body" "tlo")
("bold" "tun")
("book" "kniha")
("border" "okraj")
("both" "oba")
("bottom" "spodek")
("bottom border" "spodn okraj")
("bottom margin" "doln okraj")
("bottom padding" "spodn odskok")
("branch" "vtev")
("break" "zalomen")
("breaking" "zalamovn")
("breve" "kulat hek")
("british" "britsk")
("brown" "hnd")
("browse" "prochzet")
("browse web" "prochzet web")
("browser" "prohle")
("buffer" "snmek")
("bulgarian" "bulharsk")
("bullet" "odrka")
("bullets" "odrky")
("by" "vytvoil")
("by typing" "psanm")
("bytes free" "volnch byt")
("bytes used" "obsazench byt")
("calligraphic" "kaligrafick")
("cancel" "zruit")
("caps-lock key" "klvesa caps-lock")
("case" "case")
("cc" "slep kopie")
("cell" "buka")
("cell background color" "barva pozad buky")
("cell border" "okraj buky")
("cell height" "vka buky")
("cell operation mode" "operan reim buky")
("cell width" "ka buky")
("center" "doprosted")
("center text" "vystedit text")
("centered" "doprosted")
("centered block" "vystedn blok")
("centered tabular" "vystedn tabulka")
("change border of cell" "zmnit okraj buky")
("change cell operation mode" "zmnit operan reim buky")
("change log" "zznam zmn")
("changes" "zmny")
("chapter" "kapitola")
("check" "hek")
("check text for spelling errors" "otestovat pravopis textu")
("chinese" "ntina")
("choice" "vbr")
("citation" "citace")
("cite" "citt")
("class" "tda")
("clear" "smazat")
("clear selection" "smazat schrnku")
("clipped" "oezno")
("clipped and magnified" "oezno a zvteno")
("clipped and resized" "oezno a zmnny rozmry")
("clone" "duplikovat")
("clone window" "duplikovat okno")
("close" "zavt")
("close TeXmacs" "zavt TeXmacs")
("close buffer" "zavt snmek")
("close session" "uzavt sezen")
("close window" "zavt okno")
("closing" "uzaven")
("code" "zdrojov kd")
("color" "barva")
("column" "sloupeek")
("column contains glued items" "sloupec obsahuje pilepen poloky")
("compatibility with other formats" "kompatibilita s jinmi formty")
("compile article" "peloit lnek")
("compile book" "peloit knihu")
("compile buffer" "peloit snmek")
("compile project" "peloit projekt")
("complex" "komplexn")
("concrete" "concrete")
("condensed" "zen")
("condition" "podmnka")
("configuration" "nastaven")
("content tag" "znaka obsahu")
("context dependent icons" "kontextov zvisl ikony")
("continuation of" "obnoven innosti")
("convention" "konvence")
("converters to other data formats" "pevade do jinch datovch formt")
("copy" "koprovat")
("copy text" "koprovat text")
("copy to" "koprovat do schrnky")
("copying" "koprovn")
("corollary" "korolr")
("correct text" "opravit text")
("cursors" "kurzor")
("custom tab" "vlastn tabultor")
("customizing TeXmacs" "pizpsoben TeXmacsu")
("customizing the TeXmacs styles" "pizpsoben styl TeXmacsu")
("custum tab" "vlastn tabultor")
("cut" "vyjmout")
("cut text" "vyjmout text")
("cut to" "vyjmout do")
("cypriot" "cypriot")
("cyrillic" "azbuka")
("cyrillic input method" "metoda vstupu cyrilice")
("cyrillic italic right" "kurzvn azbuka")
("czech" "etina")
("dancers" "dancers")
("danish" "dnsk")
("dash" "pomlka")
("dashes" "pomlky")
("data conversion" "pevod dat")
("data format" "formt dat")
("date" "datum")
("deactivate" "deaktivovat")
("deactivate table" "deaktivovat tabulku")
("december" "prosinec")
("decorate atoms" "ozdobn atomy")
("default" "standardn")
("default padding" "standardn odskakovn")
("definition" "definice")
("delete" "smazat")
("delete column" "smazat sloupec")
("delete row" "smazat dek")
("denominator" "jmenovatel")
("description" "popis")
("destination" "cl")
("detach" "odpojit")
("determinant" "determinant")
("devangari" "devangari")
("developers guide" "prvodce vvoje")
("directory" "adres")
("disable first indentation" "zakzat odsazen prvnho")
("disable first indentation after" "zakzat odsazen prvnho ped")
("disable first indentation before" "zakzat odsazen prvnho ped")
("disable indentation" "zakzat odsazen")
("disable indentation after" "zakzat odsazen za")
("disable indentation before" "zakzat odsazen ped")
("disable last indentation" "zakzat odsazen poslednho")
("disable last indentation after" "zakzat odsazen poslednho")
("disable last indentation before" "zakzat odsazen poslednho")
("disallow" "nepovolit")
("distribute unused space" "rozloit nepouit mezery")
("div" "podl")
("document" "dokument")
("document format" "formt dokumentu")
("document style" "styl dokumentu")
("document styles" "styly dokument")
("documentation" "dokumentace")
("documents are trees" "dokumenty jsou stromov")
("dot" "teka")
("dots" "teky")
("double stroke" "dvakrt pekrtnut")
("down" "dol")
("dpi" "dpi")
("duplicate" "duplikovat")
("dutch" "holandtina")
("dynamic libraries" "dynamick knihovny")
("edit" "pravy")
("editing tools" "editan nstroje")
("email" "email")
("emphasize" "zvraznn")
("emphasize text" "zdraznit text")
("empty box" "przn box")
("enable first indentation" "povolit odsazen prvnho")
("enable first indentation after" "povolit odsazen prvnho")
("enable first indentation before" "povolit odsazen prvnho")
("enable indentation" "povolit odsazen")
("enable indentation after" "povolit odsazen za")
("enable indentation before" "povolit odsazen ped")
("enable last indentation" "povolit odsazen poslednho")
("enable last indentation after" "povolit odsazen poslednho ped")
("enable last indentation before" "povolit odsazen poslednho ped")
("encl" "plohy")
("end" "konec")
("english" "anglitina")
("enter a title" "vloit titulek")
("enumerate" "slovan seznam")
("enumerate|Alpha" "slovn|Abecedn")
("enumerate|Roman" "slovn|msk")
("enumerate|alpha" "slovn|abecedn")
("enumerate|roman" "slovn|msk")
("env" "prosted")
("environment" "prosted")
("epilogue" "epilog")
("equal" "rovno")
("equation" "rovnice")
("equations" "soustava rovnic")
("equivalent for" "ekvivalent pro")
("error" "chyba")
("esperanto" "esperanto")
("etruscan" "etrusk")
("evaluate" "vyhodnotit")
("evaluate scheme expression" "vyhodnotit vraz scheme")
("even page footer" "zpat sud strnky")
("even page header" "zhlav sud strnky")
("even page margin" "okraj sud strnky")
("even page text" "text sud strnky")
("exact horizontal" "pesn vodorovn")
("exact mode" "pesn reim")
("exam" "zkouka")
("example" "pklad")
("exclusive" "vyjma")
("exclusive or" "nonekvivalence")
("executable" "spustiteln")
("execute" "spustit")
("execute a TeXmacs command" "vykonat pkaz TeXmacsu")
("execute system command" "vykonat systmov pkaz")
("executive" "executive")
("exercise" "cvien")
("expand" "expandovat")
("explained" "vysvtlen")
("export" "export")
("export as" "exportovat do")
("extend or normal" "rozen nebo normln")
("extern " "extern")
("extra" "extra")
("extract format" "zskej formt")
("family" "rodina")
("february" "nor")
("figure" "obrzek")
("file" "soubor")
("file name" "jmno souboru")
("file not found" "soubor nenalezen")
("find next match" "hledat dal")
("find text" "hledat text")
("finnish" "dokonit")
("first contact" "prvn seznmen")
("first indentation" "prvn odsazen")
("first item" "prvn poloka")
("first page" "prvn strana")
("first start" "zat od")
("flat" "zplotn")
("flexibility" "flexiblita")
("flexibility factor for vertical spacing" "initel flexibility pro svisl mezery")
("floating figure" "plovouc obrzek")
("floating object" "plovouc objekt")
("floating table" "plovouc tabulka")
("fold" "balen")
("folded" "sbaleno")
("font" "psmo")
("font base size" "zkladn velikost psma")
("font dpi" "dpi psma")
("font family" "rodina psma")
("font name" "jmno psma")
("font series" "srie psma")
("font shape" "tvar psma")
("font size" "velikost psma")
("font variant" "varianta psma")
("fonts" "psma")
("footer" "zpat")
("footnote" "poznmka pod arou")
("for" "for")
("foreground" "poped")
("foreign" "ciz")
("format" "formt")
("formatted date" "formtovan datum")
("formula" "vzorec")
("formula style" "reim vzorce")
("forward replace" "nahrazovat dopedu")
("forward search" "hledat dopedu")
("fraction" "zlomek")
("french" "francouztina")
("full manuals" "pruky v plnm znn")
("function" "funkce")
("further customization" "dal pizpsoben")
("future changes" "budouc zmny")
("gNU TeXmacs comes without any form of legal warranty" "na gNU TeXmacs se nevztahuj dn prvn nroky")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs spad pod licenci GNU")
("general architecture of TeXmacs" "celkov architektura TeXmacsu")
("general negation" "obecn negace")
("generating font file" "generuji font")
("generic" "obecn")
("georgian" "georgian")
("german" "nmina")
("getting started" "zanme")
("glossary" "glos")
("glossary entry" "poloka glose")
("glue" "slepit")
("glue decorations" "slepit dekorace")
("go" "Jdi na")
("gothic" "gotick")
("graphical interface" "grafick rozhran")
("grave" "obrcen rka")
("greater" "vt")
("greater or equal" "vt nebo rovno")
("greek" "eck")
("greek letter" "eck psmeno")
("green" "zelen")
("grey" "ed")
("group" "skupina")
("happy typing" "pjemn psan")
("has been aborted" "byl peruen")
("has completed its task" "ukonil innost")
("hat" "stka")
("header" "hlavika")
("header and footer" "zhlav a zpat")
("hebrew" "hebrejsk")
("height" "vka")
("height is exactly the specified height" "vka je pesn dle zadn")
("height is maximum of specified height and box height" "vka je maximum ze zadn a vky boxu")
("height is minimum of specified height and box height" "vka je minimum ze zadn a vky boxu")
("height magnification" "prodlouen")
("help" "npovda")
("help me" "pomozte mi")
("help us" "pomozte nm")
("here" "zde")
("home" "domovsk adres")
("horizontal" "vodorovn")
("horizontal cell alignment" "vodorovn zarovnn buky")
("horizontal ink separation" "vodorovn oddlen barvy")
("horizontal part" "vodorovn st")
("horizontal position" "vodorovn pozice")
("horizontal space" "vodorvn mezera")
("horizontal table alignment" "vodorovn zarovnn tabulky")
("horizontally align cell to the base" "zarovnat buku vodorovn k zkladn")
("horizontally center the cell" "vycentrovat buku")
("how much longer may pages become" "o kolik mohou bt strnky del")
("how much shorter may pages become" "o kolik mohou bt strnky krat")
("huge" "obrovsk")
("hungarian" "maarsk")
("hyperlink" "hyperodkaz")
("hyphenation" "dlen slov")
("icelandic" "islandsk")
("if" "if")
("image" "obrzek")
("image links" "odkazy obrzku")
("implementation" "implementace")
("import" "import")
("improving the current implementation" "zlepovn souasn implementace")
("inactive" "neaktivn")
("include" "vloit")
("include a document" "vloit dokument")
("include file" "vloit soubor")
("inclusion into TeXmacs" "zahrnut do TeXmacsu")
("inclusions" "vloen")
("indent" "odsazen")
("indentation flag" "nastaven odsazen")
("index" "rejstk")
("index entry" "poloka rejstku")
("index level" "rove indexu")
("insert" "vloit")
("insert Pr" "vloit Pr")
("insert a TeXmacs symbol" "vloit symbol TeXmacsu")
("insert a big operator" "vloit velk opertor")
("insert a binary operation" "vloit binrn operaci")
("insert a binary relation" "vloit binrn relaci")
("insert a blackboard bold character" "vloit velmi tun znak")
("insert a bold calligraphic character" "vloit tun kaligrafick znak")
("insert a bold character" "vloit tun znak")
("insert a calligraphic character" "vloit kaligrafick znak")
("insert a fraction" "vloit zlomek")
("insert a fraktur character" "vloit znak fraktur")
("insert a greek character" "vloit eck psmeno")
("insert a large left delimiter" "vloit velk lev omezova")
("insert a large right delimiter" "vloit velk prav omezova")
("insert a large separator" "vloit velk oddlova")
("insert a left subscript" "vloit lev doln index")
("insert a link" "vlote odkaz")
("insert a miscellaneous symbol" "vloit jin symbol")
("insert a new branch" "vlote novou vtev")
("insert a new item" "vloit novou poloku")
("insert a picture" "vloit obrzek")
("insert a square root" "vloit odmocninu")
("insert a table" "vloit tabulku")
("insert a table or a matrix" "vloit tabulku nebo matici")
("insert an" "vloit")
("insert an accent" "vloit rku")
("insert an arrow" "vloit ipku")
("insert an environment" "vloit prosted")
("insert an n" "vloit n")
("insert appendix" "vloit dodatek")
("insert arccos" "vloit arccos")
("insert arcsin" "vloit arcsin")
("insert arctan" "vloit arctan")
("insert arg" "vloit arg")
("insert argument" "vlote argument")
("insert automatically generated content" "vloit automaticky generovan obsah")
("insert big contour integral" "vloit integrl po kivce")
("insert big coproduct" "vloit velk coproduct")
("insert big direct sum" "vloit velk plus v koleku")
("insert big dotted point" "vloit velkou teku v koleku")
("insert big integral" "vloit velk integrl")
("insert big intersection" "vloit velk prnik")
("insert big logical and" "vloit velkou konjunkci")
("insert big logical or" "vloit velkou disjunkci")
("insert big product" "vloit velk souin")
("insert big square union" "vloit velk hranat sjednocen")
("insert big summation" "vloit velkou sumu")
("insert big tensor product" "vloit velk souin tenzor")
("insert big union" "vloit velk sjednocen")
("insert big union sum" "vloit velk sjednocujc souet")
("insert big vertical space" "vloit velkou svislou mezeru")
("insert chapter" "vloit kapitolu")
("insert column" "vloit sloupec")
("insert column to the left" "vloit sloupec nalevo")
("insert column to the right" "vloit sloupec napravo")
("insert cos" "vloit cos")
("insert cosh" "vloit cosh")
("insert cot" "vloit cot")
("insert coth" "vloit coth")
("insert csc" "vloit csc")
("insert deg" "vloit deg")
("insert det" "vloit det")
("insert dim" "vloit dim")
("insert dollar" "vloit dolar")
("insert equation" "vloit rovnici")
("insert executable markup" "vloit spustitelnou znaku")
("insert exp" "vloit exp")
("insert footnote" "vloit poznmku pod arou")
("insert formula" "vloit vzorec")
("insert gcd" "vloit gcd")
("insert hom" "vloit hom")
("insert horizontal interword space" "vloit vodorovnou mezislovn mezeru")
("insert image" "vloit obrzek")
("insert inactive markup" "vloit neaktivn znaku")
("insert inf" "vloit inf")
("insert ker" "vloit ker")
("insert lg" "vloit lg")
("insert lim" "vloit lim")
("insert liminf" "vloit liminf")
("insert limsup" "vloit limsup")
("insert ln" "vloit ln")
("insert log" "vloit log")
("insert mathematics" "vloit matematiku")
("insert max" "vloit max")
("insert medium horizontal space" "vloit stedn vodorovnou mezeru")
("insert medium vertical space" "vloit stedn svislou mezeru")
("insert min" "vloit min")
("insert negative horizontal space" "vloit zpornou vodorovnou mezeru")
("insert new item or number" "vloit novou poloku")
("insert new rows or columns" "voit nov dky nebo sloupce")
("insert or delete rows or columns" "vloit nebo smazat dky nebo sloupce")
("insert row" "vloit dek")
("insert row above" "vloit dek nad")
("insert row below" "vloit dek pod")
("insert sec" "vloit sec")
("insert section" "vloit sekci")
("insert sharp" "vloit kek")
("insert sin" "vloit sin")
("insert sinh" "vloit sinh")
("insert small horizontal space" "vloit malou vodorovnou mezeru")
("insert small vertical space" "vloit malou svislou mezeru")
("insert structural markup" "vloit strukturovanou znaku")
("insert subsection" "vloit podsekci")
("insert subsubsection" "vloit podpodsekci")
("insert sup" "vloit sup")
("insert tan" "vloit tan")
("insert tanh" "vloit tanh")
("insert thick horizontal space" "vloit velkou vodorovnou mezeru")
("interfacing" "rozhran")
("interfacing TeXmacs with other systems" "rozhran TeXmacsu s jinmi systmy")
("interjection" "citoslovce")
("interline separation" "oddlen dk")
("interline space" "mezera mezi dky")
("internationalization" "lokalizace")
("interparagraph space" "mezera mezi odstavci")
("interrupt execution" "peruit sputn")
("introduction" "vod")
("invisible" "neviditeln")
("invisible citation" "neviditeln citace")
("irish" "irsk")
("is running" "je sputn")
("is tuple" "je n-tice")
("ispell does not respond" "ispell neodpovd")
("ispell is already busy" "ispell ji pracuje")
("italian" "italtina")
("italic" "kurzva")
("italic right" "kurzva vpravo")
("itemize" "neslovan seznam")
("january" "leden")
("japanese" "japontina")
("july" "ervenec")
("june" "erven")
("justified" "zarovnn")
("justify text" "peformtovat text")
("key" "klvesa")
("keyboard" "klvesnice")
("keyboard equivalent" "klvesov zkratka")
("keyboard modifiers" "klvesov modifiktory")
("keyboard shortcut" "klvesov zkratka")
("keymaps" "mapovn klves")
("keyword" "klov slovo")
("keywords" "klov slova")
("kill" "zabt")
("known bugs" "znm chyby")
("label" "popisek")
("landscape" "na ku")
("language" "jazyk")
("large" "vt")
("large closing bracket" "velk uzavrac zvorka")
("large delimiter" "velk omezova znak")
("large opening bracket" "velk otevrac zvorka")
("large separator" "velk oddlova")
("last indentation" "posledn odsazen")
("last page" "posledn strana")
("latex command" "pkaz pro latex")
("latin" "latinka")
("layout" "vzhled")
("left" "lev")
("left border" "lev okraj")
("left margin" "lev okraj")
("left padding" "lev odskoen")
("left prime" "lev rka")
("left aligned" "zarovnn doleva")
("left slanted" "sklonn doleva")
("left subscript" "doln index vlevo")
("left superscript" "horn index vlevo")
("left surrounding" "lev okol")
("legal" "legal")
("lemma" "lemma")
("length" "dlka")
("less" "men")
("less or equal" "men nebo rovno")
("letter" "dopis")
("license" "licence")
("light" "jemn")
("limitations" "omezen")
("limits" "limity")
("line" "dek")
("line break" "zalomen dku")
("line stretch" "rozthnut dky")
("link" "odkaz")
("link image" "propojit obrzek")
("list" "seznam")
("list of figures" "seznam obrzk")
("list of tables" "seznam tabulek")
("load" "otevt")
("load LaTeX file" "otevt soubor LaTeX")
("load TeX file" "otevt soubor TeX")
("load TeXmacs file" "otevt soubor TeXmacs")
("load TeXmacs style file" "otevt soubor stylu TeXmacs")
("load a file" "otevt soubor")
("load buffer" "otevt snmek")
("load file" "otevt soubor")
("load html file" "otevt soubor html")
("load image" "otevt obrzek")
("load in new window" "nahrt do novho okna")
("load latex file" "otevt soubor LaTeX")
("load more recent autosave file" "otevt novj soubor automatick zlohy")
("load tex file" "otevt soubor TeX")
("load verbatim file" "otevt soubor verbatim")
("loaded" "oteveno")
("long" "protaen")
("look and feel" "vzhled a chovn")
("look up" "vyhledat")
("lower border" "doln okraj")
("macro" "makro")
("magenta" "fialov")
("magic" "kouzeln")
("magnification" "zvten")
("magnified" "zvteno")
("main" "hlavn")
("main icon bar" "hlavn panel nstroj")
("major changes" "hlavn zmny")
("make a page insertion" "vloen strnky")
("make a subscript" "doln index")
("make a superscript" "horn index")
("make acute" "vloit rku")
("make bar" "vloit pruh")
("make check" "vloit hek")
("make fraction" "vloit zlomek")
("make grave" "vloit obrcenou rku")
("make hat" "vloit stka")
("make label" "vytvoit nvt")
("make negation" "vloit negaci")
("make page reference" "vytvoit odkaz na stranu")
("make reference" "vytvoit odkaz")
("make square root" "vloit odmocninu")
("make tilde" "vloit vlnka")
("make title" "vytvoit titul")
("make vector" "vloit vektor")
("making donations" "finann podpora")
("manual" "pruka")
("map to" "piazen k")
("march" "bezen")
("margins" "okraje")
("margins as on paper" "okraje jako na pape")
("master" "hlavn")
("master file" "hlavn soubor")
("math" "matika")
("math font" "psmo pro matematiku")
("math font family" "rodina psma pro matematiku")
("math font series" "srie psma pro matematiku")
("math font shape" "tvar psma pro matematiku")
("mathematical" "matematick")
("mathematical formulas" "matematick vzorce")
("mathematical typesetting" "matematick sazba")
("mathematics" "matematika")
("matrix" "matice")
("maximal number of columns" "nejvy poet sloupc")
("maximal number of rows" "nejvy poet dk")
("maximum mode" "nejvy reim")
("may" "kvten")
("medium" "stedn")
("medium skip" "stedn odstup")
("meminfo" "informace o pamti")
("merge" "spojit")
("messy" "messy")
("meta key" "meta klvesa")
("middle" "prostedek")
("minimal number of columns" "nejmen poet sloupc")
("minimal number of rows" "nejmen poet dk")
("minimum mode" "nejmen reim")
("minus" "mnus")
("miscellaneous" "rzn")
("mod" "modulo")
("mode" "reim")
("modifier" "modifiktor")
("modify cell alignment" "zmnit zarovnn buky")
("modify cell border" "zmnit okraj buky")
("modify cell padding" "zmnit odskok buky")
("modify cell size" "zmnit velikost buky")
("modify table border" "zmnit okraj tabulky")
("modify table padding" "zmnit rozestup bunk")
("mongolian" "mongolsk")
("more information about GNU TeXmacs can be found in the help" "Vce informac o GNU TeXmacs mete najt v npovd")
("mosaic" "mozaika")
("move down" "pesunout dol")
("move object" "pesun objektu")
("move to the right when finished" "pesunout vpravo po ukonen")
("move up" "pesunout nahoru")
("n-th" "n-t")
("n-th root" "n-t odmocnina")
("name" "jmno")
("negation" "negace")
("new" "nov")
("new buffer" "nov snmek")
("new column" "nov sloupec")
("new item" "nov poloka")
("new line" "nov dek")
("new number" "nov slo")
("new page" "nov strnka")
("new page before" "nov strana ped")
("new paragraph" "nov odstavec")
("new roman" "new roman")
("new row" "nov dek")
("new table" "nov tabulka")
("next line" "dal dek")
("no changes need to be saved" "dn zmny pro uloen")
("no dictionary for" "chyb slovnk")
("no first indentation" "neodsazovat prvn")
("no indentation" "bez odsazen")
("no last indentation" "neodsazovat posledn")
("no line break" "nezalamovat dek")
("no matches found" "nic nenalezeno")
("no more matches for" "nelze nalzt dal")
("no more redo information available" "nen mon provst akci 'znovu'")
("no more undo information available" "nen mon provst akci 'zpt'")
("no name" "bezejmna")
("no page break after" "nezalamovat strnku za")
("no page break before" "nezalamovat strnku ped")
("no spelling errors found in text" "nebyly nalezeny pravopisn chyby")
("no style" "dn styl")
("none" "dn")
("normal" "normln")
("norwegian" "norsk")
("not" "non")
("not equal" "nerovno")
("not found" "nenalezen")
("notation" "notace")
("note" "poznmka")
("november" "listopad")
("number" "slo")
("number equation" "slovat rovnice")
("number of columns" "poet sloupc")
("numbered equation" "slovan rovnice")
("numbered equations" "slovan soustava rovnic")
("numerator" "itatel")
("numeric" "seln")
("objectives" "cle")
("occurrences" "vskyt")
("october" "jen")
("odd page footer" "zpat lich strnky")
("odd page header" "zhlav lich strnky")
("odd page margin" "okraj lich strnky")
("odd page text" "text lich strnky")
("off" "vypnuto")
("ok" "ok")
("old english" "staroanglick")
("old slavonic" "staroslovnsk")
("old style" "star styl")
("on" "zapnuto")
("on cells" "na buky")
("on columns" "na sloupce")
("on entire table" "na celou tabulku")
("on rows" "na dky")
("one spelling error has been corrected" "jedna pravopisn chyba opravena")
("online documentation" "online dokumentace")
("online help" "online npovda")
("open" "otevt")
("open a new buffer" "otevt nov snmek")
("open new window" "otevt nov okno")
("opening" "otevrn")
("operation on named selection" "operace s pojmenovanm vbrem")
("operation on primary selection" "operace s primrnm vbrem")
("operation on secondary selection" "operace se sekundrnm vbrem")
("operation on ternary selection" "operace s tercirnm vbrem")
("optical" "optical")
("option" "nastaven")
("options" "nastaven")
("or" "nebo")
("orange" "oranov")
("orientation" "orientace")
("origin" "pvod")
("original welcome message" "pvodn pivtac hlka")
("other" "jin")
("other pages" "jin strnky")
("other projects" "jin projekty")
("other style" "jin styl")
("outlined roman" "roman obrysov")
("over" "nad")
("padding" "odskakovn")
("page" "strana")
("page bottom margin" "doln okraj strnky")
("page break" "zalomen strnky")
("page break before" "zlom strany ped")
("page height" "vka strnky")
("page insertion" "vloen strnky")
("page layout" "vzhled strnky")
("page number text" "text pro slovn stran")
("page numbering" "slovn strnek")
("page reference" "odkaz na strnku")
("page right margin" "prav okraj strnky")
("page top margin" "horn okraj strnky")
("page type" "typ strnky")
("page width" "ka strnky")
("paper" "papr")
("paper type" "velikost papru")
("papyrus" "papyrus")
("paragraph" "odstavec")
("paragraph mode" "reim odstavce")
("paragraph width" "ka odstavce")
("part" "st")
("past changes" "minul zmny")
("paste" "vloit")
("paste from" "vloit ze schrnky")
("paste text" "vloit text")
("path" "cesta")
("perform operations on cells" "provst operace na bukch")
("perform operations on columns" "provst operace na sloupcch")
("perform operations on entire table" "provst operace na cel tabulce")
("perform operations on rows" "provst operace na dcch")
("permanent" "permanentn")
("person" "osoba")
("personal dictionary has been modified" "osobn slovnk byl zmnn")
("phantasy" "fantazie")
("philosophy" "filosofie")
("phoenician" "fnick")
("phonetic" "fonetick")
("pink" "rov")
("plain block" "prost blok")
("plain tabular" "prost tabulka")
("planned changes" "plnovan zmny")
("plans for the future" "plny do budoucna")
("please" "prosm")
("please wait" "ekejte, prosm")
("plus" "plus")
("polish" "poltina")
("porting TeXmacs to other platforms" "portace TeXmacsu na dal platformy")
("portrait" "portrt")
("portuguese" "portugaltina")
("position" "pozice")
("position float" "umstit plovouc")
("position floating object" "umstit plovouc objekt")
("position the table" "umstit tabulku")
("postscript" "postscript")
("postscript image" "postscriptov obrzek")
("pre-alpha release" "pre-alpha release")
("preamble" "preambule")
("preamble mode" "reim preambule")
("preferences" "nastaven")
("presentation mode" "reim prezentace")
("preview before printing" "nhled ped tiskem")
("preview with ghostview" "nhled pes ghostview")
("primary" "prvn")
("prime" "rka")
("print" "tisknout")
("print all" "tisknout ve")
("print all to file" "tisknout do souboru")
("print page selection" "tisknout vbr stran")
("print page selection to file" "tisknout vbr stran do souboru")
("print to postscript file" "tisknout do postscriptovho souboru")
("printer" "tiskrna")
("printer dpi" "dpi tiskrny")
("printing command" "pkaz pro tisk")
("problem" "pklad")
("professional" "profesionln")
("prog" "prog")
("prog font" "psmo pro programy")
("prog font family" "rodina psma pro programy")
("prog font series" "srie psma pro programy")
("prog font shape" "tvar psma pro programy")
("program" "program")
("program mode" "reim programu")
("programming" "programovn")
("progressive" "progresvn")
("project" "projekt")
("projects" "projekty")
("prologue" "prolog")
("prompt on scripts" "dotzat se pi skriptu")
("proof" "dkaz")
("proportional" "proporcionln")
("proportional typewriter" "proporcionln psac stroj")
("proposition" "tvrzen")
("query replace" "dotzat se ped nhradou")
("quit" "konec")
("quotation" "citt")
("quote" "uvozovky")
("range" "rozsah")
("really close it" "opravdu uzavt")
("really huge" "vskutku velk")
("really quit" "opravdu ukonit")
("red" "erven")
("redo" "znovu")
("redo undone changes" "znovu posledn pravy")
("reduce bottom margin by" "zmenit doln okraj o")
("reduce left margin by" "zmenit lev okraj o")
("reduce margins" "zmenit okraje")
("reduce right margin by" "zmenit prav okraj o")
("reduce top margin by" "zmenit horn okraj o")
("reduction even page margin" "zmenen okraje sud strnky")
("reduction odd page margin" "zmenen okraje lich strnky")
("reduction page bottom margin" "zmenen dolnho okraje strnky")
("reduction page right margin" "zmenen pravho okraje strnky")
("reduction page top margin" "zmenen hornho okraje strnky")
("reference" "reference")
("references" "odkazy")
("regular" "regulrn")
("release" "release")
("reload" "znova nahrt")
("remark" "anotace")
("remove number" "odebrat slo")
("remove this switch" "odebrat pepna")
("renumber this page" "znovu oslovat tuto stranu")
("repeat object" "zopakovat objekt")
("replace" "nahradit")
("replace by" "nahradit")
("replaced" "nahrazeno")
("replaced one occurrence" "nahrazen jeden vskyt")
("reset" "reset")
("resize object" "zmna rozmr objektu")
("resized" "zmnny rozmry")
("return" "return")
("revert" "zpt")
("revert buffer" "obnovit snmek")
("right" "prav")
("right border" "prav okraj")
("right margin" "prav okraj")
("right padding" "odskakovn vpravo")
("right aligned" "zarovnn doprava")
("right subscript" "doln index vpravo")
("right superscript" "horn index vpravo")
("right surrounding" "prav okol")
("rigid" "pevn")
("rigid horizontal" "pevn ")
("rigid space" "pevn mezera")
("romanian" "rumuntina")
("root" "koen")
("rotate backward" "petoit nazpt")
("rotate forward" "petoit dopedu")
("row" "dek")
("row contains glued items" "dek obsahuje pilepen poloky")
("runic" "runy")
("running author" "autor")
("running title" "titul (nzev)")
("russian" "rutina")
("russian and Ukrainian users" "uivatel z Ruska a Ukrajiny")
("sample" "pklad")
("sans serif" "bez patek")
("save" "uloit")
("save TeXmacs file" "uloit soubor TeXmacs")
("save TeXmacs style file" "uloit soubor stylu TeXmacs")
("save as" "uloit jako")
("save as LaTeX" "uloit jako LaTeX")
("save as TeX" "uloit jako TeX")
("save buffer" "uloit snmek")
("save buffer as" "uloit snmek jako")
("save file" "uloit soubor")
("save html file" "uloit soubor html")
("save image" "uloit obrzek")
("save latex file" "uloit soubor LaTeX")
("save tex file" "uloit soubor TeX")
("save this buffer" "uloit tento snmek")
("save verbatim file" "uloit soubor verbatim")
("saved" "uloeno")
("screen layout" "rozvren obrazovky")
("screen margins" "okraje na obrazovce")
("script" "indexy")
("script above" "index nad")
("script below" "index pod")
("script script size" "velikost indexu indexu")
("script size" "velikost indexu")
("scripts not accepted" "skripty nejsou povoleny")
("search" "hledat")
("searching" "hledm")
("secondary" "druh")
("section" "sekce")
("security" "zabezpeen")
("see" "viz")
("select a document style" "vyberte styl dokumentu")
("select a foreground color" "vybrat barvu poped")
("select a language" "vyberte jazyk")
("selected region" "vybran oblast")
("selection" "vbr")
("selections" "vbry")
("seminar" "semin")
("separation between lines" "oddlen dk")
("separation between paragraphs" "oddlen odstavc")
("separator" "oddlova")
("september" "z")
("serb" "srbsk")
("series" "srie")
("series|right" "srie|right")
("session" "sezen")
("session name" "jmno sezen")
("session type" "typ sezen")
("sessions" "sezen")
("set" "nastavit")
("set background color of cell" "nastavit barvu pozad buky")
("set cell mode" "nastavit reim buky")
("set extension center" "nastavit sted rozen")
("set height" "nastavit vku")
("set height of cell" "nastavit vku buky")
("set margins" "nastavit okraje")
("set n" "nastavte n")
("set paragraph margins" "nastavit okraje odstavce")
("set paragraph mode" "nastavit reim odstavce")
("set printer dpi" "nastaven dpi tiskrny")
("set printing command" "nastaven tiskovho pkazu")
("set span" "nastavit rozpt")
("set special cell properties" "nastavit spec. vlastnosti buky")
("set special table properties" "nastavit spec. vlastnosti tabulky")
("set text width" "nastavit ku textu")
("set width" "nastavit ku")
("set width of cell" "nastavit ku buky")
("settings" "nastaven")
("setup printer" "nastaven tiskrny")
("shape" "tvar")
("shift-down" "shift-dol")
("shift-right" "shift-doprava")
("show" "ukzat")
("show header and footer" "ukazovat zhlav a zpat")
("show on screen" "na obrazovku")
("shrinking factor" "zmenen")
("signature" "podpis")
("size" "velikost")
("size limits" "omezen velikosti")
("slanted" "sklonn")
("sloppy" "nedbal")
("small" "men")
("small caps" "kapitlky")
("small figure" "mal obrzek")
("small skip" "mal odstup")
("small table" "mal tabulka")
("source code" "zdrojov kd")
("space" "mezera")
("space between lines" "mezery mezi dky")
("space between paragraphs" "mezery mezi odstavci")
("spacing" "prokldn")
("spanish" "panltina")
("special" "speciln")
("special cell properties" "spec. vlastnosti buky")
("special table properties" "spec. vlastnosti tabulky")
("specific" "specifick")
("spell" "pravopis")
("spell checking complete" "kontrolo pravopisu dokonena")
("spelling error" "pravopisn chyba")
("spelling errors have been corrected" "pravopisn chyby byly opraveny")
("split" "oddlit")
("square root" "odmocnina")
("start" "zatek")
("start a new chapter" "zat novou kapitolu")
("start a new section" "zat novou sekci")
("start an interactive session" "spustit interaktivn sezen")
("status bar" "stavov dek")
("stretchable" "zvtiteln")
("stretchable horizontal" "vodorovn roziiteln")
("stretchable vertical" "svisle prodlouiteln")
("stroke" "pekrtnut")
("strokes" "pekrtnut")
("strong" "siln")
("structural" "strukturovan")
("style" "styl")
("styles" "styly")
("sub" "pod-")
("subparagraph" "pododstavec")
("subscript" "doln index")
("subsection" "podsekce")
("subsub" "podpod-")
("subsubsection" "podposekce")
("summary" "souhrn")
("summary of the principal TeXmacs tags" "souhrn hlavnch teg TeXmacsu")
("superpose" "superpozice")
("superposed" "superponovn")
("superscript" "horn index")
("swedish" "vdtina")
("switch" "pepna")
("switch to first" "prvn pepna")
("switch to formula style" "pepnout do stylu vzorc")
("switch to last" "posledn pepna")
("switch to next" "dal pepna")
("switch to previous" "pedchoz pepna")
("switching and folding" "pepnn a balen")
("symbol" "symbol")
("system environment variables" "systmov promnn")
("tab" "tab")
("table" "tabulka")
("table command" "pkaz tabulky")
("table of contents" "obsah")
("tables" "tabulky")
("tabular" "tabulovat")
("tabular material" "tabelrn materil")
("teXmacs as an interface" "TeXmacs jako rozhran")
("teXmacs fonts" "fonty TeXmacsu")
("teXmacs notice" "poznmka TeXmacsu")
("teXmacs style files" "soubory se styly TeXmacsu")
("ternary" "tet")
("test" "test")
("tex" "TeX")
("text" "text")
("text font" "psmo pro text")
("text height correction" "oprava vky textu")
("text width" "ka textu")
("texts" "texty")
("th century bc" "th century bc")
("th root" "-t odmocnina")
("thai" "thai")
("the TeXmacs authors" "autoi TeXmacsu")
("the application did not send its usual startup banner" "aplikace nezaslala obvyklou startovac zprvu")
("the application does not reply" "aplikace neodpovd")
("the application is already running" "aplikace je ji sputna")
("the boxes produced by the typesetter" "boxy produkovan sazeem")
("the graphical user interface" "grafick uivatelsk rozhran")
("the leaves of TeXmacs trees" "listy stromu TeXmacsu")
("the mycas example" "pklad mycas")
("the primitive TeXmacs constructs" "primitivn konstrukty TeXmacsu")
("the standard TeXmacs styles" "standardn styly TeXmacsu")
("theorem" "teorm")
("there are unsaved files" "nkter soubory nejsou uloeny")
("this buffer has not been saved" "tento snmek nebyl uloen")
("this document has been produced using" "tento dokumenty byl vytvoen pouitm")
("this line" "tento dek")
("this page" "tato strnka")
("tilda" "tilda")
("tilde" "vlnka")
("times" "times")
("tiny" "mrav")
("title" "titul")
("to the left" "nalevo")
("to the right" "napravo")
("today" "dnes")
("tools" "nstroje")
("top" "vrch")
("top border" "horn okraj")
("top level" "nejvy rove")
("top margin" "horn okraj")
("top padding" "horn odskok")
("translate" "peloit")
("tree" "strom")
("tuple" "n-tice")
("turkish" "tureck")
("tutorial" "prvodce zatenka")
("type" "typ")
("type a latex command followed by" "napit pkaz pro latex nsledovan")
("type body" "napite tlo")
("type denominator" "napit jmenovatel")
("type numerator" "napit itatel")
("type script" "napite skript")
("typesetted boxes" "szen box")
("typewriter" "psac stroj")
("typewriter small caps" "psac stroj kapitlky")
("typing a simple text" "psan jednoduchho textu")
("typing simple texts" "psan jednoduchch text")
("ugaritic" "ugaritic")
("ukrainian" "ukrajintina")
("undo" "zpt")
("undo last changes" "zpt posledn pravy")
("up" "nahoru")
("update" "obnovit")
("update from web" "aktualizace z webu")
("update image links" "aktualizovat odkazy obrzk")
("upper border" "horn okraj")
("use TeXmacs" "pouvejte TeXmacs")
("use a black color" "pout ernou barvu")
("use a blue color" "pout modrou barvu")
("use a bold font" "pout tun psmo")
("use a brown color" "pout hndou barvu")
("use a calligraphic font" "pout kaligrafick psmo")
("use a green color" "pout zelenou barvu")
("use a grey color" "pout edou barvu")
("use a magenta color" "pout fialovou barvu")
("use a orange color" "pout oranovou barvu")
("use a pink color" "pout rovou barvu")
("use a red color" "pout ervenou barvu")
("use a sans serif font" "pout bezpatkov psmo")
("use a typewriter font" "pout psmo psacho stroje")
("use a white color" "pout blou barvu")
("use a yellow color" "pout lutou barvu")
("use blackboard bold font" "pout psmo blackboard")
("use bold font series" "pout tun psmo")
("use calligraphical font" "pout kaligrafick psmo")
("use footnote font size" "pout velikost psma poznmky pod arou")
("use fraktur font" "pout psmo fraktur")
("use huge font size" "pout obrovsk psmo")
("use italic font shape" "pout kurzvn psmo")
("use large font size" "pout vt psmo")
("use left hand column as border" "pout lev sloupec jako okraj")
("use medium font series" "pout polotun psmo")
("use normal font size" "pout stedn psmo")
("use package" "pouit balku")
("use paragraph width" "pout ku odstavce")
("use really huge font size" "pout vskutku obrovsk psmo")
("use right font shape" "pout psmo kurzvn vpravo")
("use right hand column as border" "pout prav sloupec jako okraj")
("use roman font family" "pout psmo roman")
("use row above as border" "pout horn dek jako okraj")
("use row below as border" "pout spodn dek jako okraj")
("use sans serif font family" "pout bezpatkov psmo")
("use script font size" "pout velikost psma indexu")
("use slanted font shape" "pout sklonn psmo")
("use small capitals" "pout kapitlky")
("use small font size" "pout mal psmo")
("use small-caps font shape" "pout kapitlky")
("use the blackboard bold font" "pout tun psmo blackboard")
("use the fraktur font" "pout psmo fraktur")
("use tiny font font size" "pout mrav psmo")
("use typewriter font family" "pout psmo psacho stroje")
("use very large font size" "pout velk psmo")
("user manual" "uivatelsk pruka")
("user provided icons" "uivatelsk ikony")
("value" "hodnota")
("variable" "promnn")
("variant" "variant")
("vector" "vektor")
("verbatim" "verbatim")
("verse" "ver")
("vertical" "svisl")
("vertical after" "svisl za")
("vertical before" "svisl ped")
("vertical cell alignment" "svisl zarovnn buky")
("vertical part" "svisl st")
("vertical position" "svisl pozice")
("vertical space" "svisl mezera")
("vertical table alignment" "svisl zarovnn tabulky")
("vertically align cell to the base" "zarovnat buku svisle na zkladnu")
("vertically center the cell" "vystedit buku svisle")
("very large" "velk")
("very small" "mal")
("vietnamese" "vietnamsk")
("view" "pohled")
("visible" "viditeln")
("warning" "varovn")
("welcome" "vtejte")
("welcome to GNU TeXmacs" "Vtejte v GNU TeXmacs")
("what is new" "co je novho")
("when finished" "po ukonen")
("while" "while")
("white" "bl")
("wide accent" "irok akcent")
("width" "ka")
("width is exactly the specified width" "ka je pesn podle zadn")
("width is maximum of specified width and box width" "ka je maximum zadan ky a ky boxu")
("width is minimum of specified width and box width" "ka je minimum zadan ky a ky boxu")
("width magnification" "rozen")
("window" "okno")
("window height" "vka okna")
("window width" "ka okna")
("windows key" "klvesa windows")
("with" "s")
("write a name" "pout kapitlky")
("write bold mathematics" "pout tun matematick psmo")
("write bold text" "pout tun psmo")
("write italic text" "pout kurzvn psmo")
("write sample text" "pout bezpatkov psmo")
("write strong text" "pout siln psmo")
("write typewriter text" "pout psmo psacho stroje")
("write verbatim text" "pout reim verbatim")
("writing data converters" "tvorba konvertor dat")
("writing your own style files" "tvorba vaich vlastnch soubor styl")
("yellow" "lut")
("you can also obtain" "me tak zskat")
("your document is back in its original state" "v dokument je opt v pvodn stavu")
("your first interface" "vae prvn rozhran")
